==> com.liferay.layout.impl-4.0.45-sources.jar: com/liferay/layout/internal/template/util/LayoutConverterRegistryImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.internal.template.util;

import com.liferay.layout.util.template.LayoutConverter;
import com.liferay.layout.util.template.LayoutConverterRegistry;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMap;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMapFactory;

import org.osgi.framework.BundleContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;

/**
 * @author Eudaldo Alonso
 */
@Component(immediate = true, service = LayoutConverterRegistry.class)
public class LayoutConverterRegistryImpl implements LayoutConverterRegistry {

	@Override
	public LayoutConverter getLayoutConverter(String layoutTemplateId) {
		return _layoutConverters.getService(layoutTemplateId);
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_layoutConverters = ServiceTrackerMapFactory.openSingleValueMap(
			bundleContext, LayoutConverter.class, "layout.template.id");
	}

	private ServiceTrackerMap<String, LayoutConverter> _layoutConverters;

}

==> com.liferay.layout.impl-5.0.9-sources.jar: com/liferay/layout/internal/template/util/LayoutConverterRegistryImpl.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.layout.internal.template.util;

import com.liferay.layout.util.template.LayoutConverter;
import com.liferay.layout.util.template.LayoutConverterRegistry;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMap;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMapFactory;

import org.osgi.framework.BundleContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Eudaldo Alonso
 */
@Component(immediate = true, service = LayoutConverterRegistry.class)
public class LayoutConverterRegistryImpl implements LayoutConverterRegistry {

	@Override
	public LayoutConverter getLayoutConverter(String layoutTemplateId) {
		LayoutConverter layoutConverter = _layoutConverters.getService(
			layoutTemplateId);

		if (layoutConverter == null) {
			layoutConverter = _defaultLayoutConverter;
		}

		return layoutConverter;
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_layoutConverters = ServiceTrackerMapFactory.openSingleValueMap(
			bundleContext, LayoutConverter.class, "layout.template.id");
	}

	@Reference(target = "(layout.template.id=default)")
	private LayoutConverter _defaultLayoutConverter;

	private ServiceTrackerMap<String, LayoutConverter> _layoutConverters;

}
